@@ -2,7 +2,7 @@
 
 package Games::Nintendo::Mario;
 
-our $VERSION = '0.09_01';
+use Carp qw(cluck);
 
 =head1 NAME
 
@@ -26,14 +26,12 @@ change his state.
 =cut
 
 use strict;
-use warnings;
 
-use Carp qw(cluck);
+our $VERSION = 0.01;
 
 sub _names  { qw[Mario Luigi] }
 sub _states { qw[normal] }
 sub _items  { () }
-sub _other_defaults { () }
 
 sub _goto_hash   {
 	{ damage => 'dead' }
@@ -82,8 +80,7 @@ sub new {
 
 	my $plumber = {
 		state => $args{state},
-		name  => $args{name},
-		$class->_other_defaults
+		name  => $args{name}
 	};
 
 	bless $plumber => $class;
