@@ -2,13 +2,8 @@
 
 package Games::Nintendo::Mario::SMB3;
 
-our $VERSION = '0.09_01';
-
 use base qw(Games::Nintendo::Mario);
 
-use strict;
-use warnings;
-
 sub _names  { qw[Mario Luigi] }
 sub _states { qw[normal super fire raccoon tanooki frog hammer pwing] }
 sub _items  { qw[mushroom flower leaf tanookisuit frogsuit hammersuit pwing] }
